complete -c sniffglue -s n -l threads -d 'Number of packet parsing threads (defaults to number of cpu cores)' -r
complete -c sniffglue -l gen-completions -d 'Generate shell completions' -r -f -a "{bash\t'',elvish\t'',fish\t'',powershell\t'',zsh\t''}"
complete -c sniffglue -s p -l promisc -d 'Set device to promiscuous mode'
complete -c sniffglue -l debugging -d 'Show fully dissected packets with all headers for development'
complete -c sniffglue -s j -l json -d 'Json output (unstable)'
complete -c sniffglue -s v -l verbose -d 'Increase filter sensitivity to show more (possibly less useful) packets. The default only shows few packets, this flag can be specified multiple times. (maximum: 4)'
complete -c sniffglue -s r -l read -d 'Open a pcap file instead of a device'
complete -c sniffglue -l insecure-disable-seccomp -d 'Disable syscall filter sandbox, this flag disables security features in sniffglue, please file a bug report if you need this option'
complete -c sniffglue -s h -l help -d 'Print help'
